==> ?f=K2_v2.0.0.zip: modules/mod_k2_tools/tmpl/search.php <==
<?php
/*
// "K2 Tools" Module by JoomlaWorks for Joomla! 1.5.x - Version 2.0
// Copyright (c) 2006 - 2009 JoomlaWorks Ltd. All rights reserved.
// Released under the GNU/GPL license: http://www.gnu.org/copyleft/gpl.html
// More info at http://www.joomlaworks.gr and http://k2.joomlaworks.gr
// Designed and developed by the JoomlaWorks team
// *** Last update: August 6th, 2009 ***
*/

// no direct access
defined('_JEXEC') or die ('Restricted access');

?>

<div id="k2ModuleBox<?php echo $module->id; ?>" class="k2SearchBlock <?php echo $params->get('moduleclass_sfx'); ?>">
  <form action="<?php echo JRoute::_('index.php?option=com_k2&view=itemlist&task=search'); ?>" method="get">
    <?php $app =& JFactory::getApplication(); if (!$app->getCfg('sef')): ?>
    <input type="hidden" name="option" value="com_k2" />
    <input type="hidden" name="view" value="itemlist" />
    <input type="hidden" name="task" value="search" />
    <?php endif; ?>
    
    <input name="searchword" maxlength="<?php echo $maxlength; ?>" alt="<?php echo $button_text; ?>" class="inputbox<?php echo $moduleclass_sfx; ?>" type="text" size="<?php echo $width; ?>" value="<?php echo $text; ?>" onblur="if(this.value=='') this.value='<?php echo $text; ?>';" onfocus="if(this.value=='<?php echo $text; ?>') this.value='';" />
    
    <?php if ($button):?>
    <?php if ($imagebutton):?>
    <input type="image" value="<?php echo $button_text; ?>" class="button<?php echo $moduleclass_sfx;?>" src="<?php echo $img; ?>" onclick="this.form.searchword.focus();"/>
    <?php else:?>
    <input type="submit" value="<?php echo $button_text; ?>" class="button<?php echo $moduleclass_sfx; ?>" onclick="this.form.searchword.focus();"/>
    <?php endif;?>
    <?php endif; ?>
  </form>
</div>

==> ?f=K2_v2.2.0.zip: modules/mod_k2_tools/tmpl/search.php <==
<?php
/**
 * @version		$Id: search.php 303 2010-01-07 02:56:33Z joomlaworks $
 * @package		K2
 * @author    JoomlaWorks http://www.joomlaworks.gr
 * @copyright	Copyright (c) 2006 - 2010 JoomlaWorks Ltd. All rights reserved.
 * @license		GNU/GPL license: http://www.gnu.org/copyleft/gpl.html
 */

// no direct access
defined('_JEXEC') or die('Restricted access');

?>

<div id="k2ModuleBox<?php echo $module->id; ?>" class="k2SearchBlock <?php echo $params->get('moduleclass_sfx'); ?>">
  <form action="<?php echo JRoute::_('index.php?option=com_k2&view=itemlist&task=search'); ?>" method="get">
    <?php $app =& JFactory::getApplication(); if (!$app->getCfg('sef')): ?>
    <input type="hidden" name="option" value="com_k2" />
    <input type="hidden" name="view" value="itemlist" />
    <input type="hidden" name="task" value="search" />
    <?php endif; ?>
    
    <input name="searchword" maxlength="<?php echo $maxlength; ?>" alt="<?php echo $button_text; ?>" class="inputbox<?php echo $moduleclass_sfx; ?>" type="text" size="<?php echo $width; ?>" value="<?php echo $text; ?>" onblur="if(this.value=='') this.value='<?php echo $text; ?>';" onfocus="if(this.value=='<?php echo $text; ?>') this.value='';" />
    
    <?php if ($button):?>
    <?php if ($imagebutton):?>
    <input type="image" value="<?php echo $button_text; ?>" class="button<?php echo $moduleclass_sfx;?>" src="<?php echo $img; ?>" onclick="this.form.searchword.focus();"/>
    <?php else:?>
    <input type="submit" value="<?php echo $button_text; ?>" class="button<?php echo $moduleclass_sfx; ?>" onclick="this.form.searchword.focus();"/>
    <?php endif;?>
    <?php endif; ?>
  </form>
</div>
